import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { FormControl } from '@angular/forms';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-add-clients-to-subnet',
  templateUrl: './add-clients-to-subnet.component.html',
  styleUrls: ['./add-clients-to-subnet.component.css']
})
export class AddClientsToSubnetComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  units: any[] = [];
  clients: any[] = [];
  selectedClients: string[] = [];
  loading: boolean = true;
  unitControl = new FormControl();
  childUnitControl = new FormControl();

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<AddClientsToSubnetComponent>,
    private toastService: ToastrService,
    @Inject(MAT_DIALOG_DATA) public data: { subnetUuid: string, subnetName: string }
  ) {}

  ngOnInit(): void {
    this.loading = true;
    this.loadUnits();
  }

  loadUnits() {
    this.http.get<any>(`${this.baseUrl}/organizational-units?type=classroom&page=1&itemsPerPage=50`).subscribe(
      response => {
        this.units = response['hydra:member'];
        this.loading = false;
      },
      error => console.error('Error fetching organizational units:', error)
    );
  }

  loadChildUnits(unitId: string) {
    this.http.get<any>(`${this.baseUrl}/clients?parent.id${unitId}`).subscribe(
      response => {
        this.clients = response['hydra:member'];
      },
      error => console.error('Error fetching child units:', error)
    );
  }

  toggleClientSelection(clientId: string): void {
    const index = this.selectedClients.indexOf(clientId);
    if (index >= 0) {
      this.selectedClients.splice(index, 1);
    } else {
      this.selectedClients.push(clientId);
    }
  }

  save() {
    this.selectedClients.forEach(clientId => {
      const postData = { client: `/clients/${clientId}` };

      this.http.post(`${this.baseUrl}/og-dhcp/server/${this.data.subnetUuid}/post-host`, postData).subscribe(
        response => {
          this.toastService.success(`Cliente asignado correctamente`);
        },
        error => {
          console.error(`Error al asignar el cliente:`, error);
          this.toastService.error(`Error al asignar el cliente: ${error.error['hydra:description']}`);
        }
      );
    });

    this.dialogRef.close(this.selectedClients);
  }

  close() {
    this.dialogRef.close();
  }
}
